@@ -21,21 +21,25 @@
 
 /**
  * SECTION:element-nuvdemux
- * @see_also: mythtvsrc
  *
+ * <refsect2>
+ * <para>
  * Demuxes MythTVs NuppelVideo .nuv file into raw or compressed audio and/or
  * video streams.
- * 
+ * </para>
+ * <para>
  * This element currently only supports pull-based scheduling.
- * 
- * <refsect2>
+ * </para>
  * <title>Example launch line</title>
- * |[
+ * <para>
+ * <programlisting>
  * gst-launch filesrc test.nuv ! nuvdemux name=demux  demux.audio_00 ! decodebin ! audioconvert ! audioresample ! autoaudiosink   demux.video_00 ! queue ! decodebin ! ffmpegcolorspace ! videoscale ! autovideosink
- * ]| Play (parse and decode) an .nuv file and try to output it to
+ * </programlisting>
+ * Play (parse and decode) an .nuv file and try to output it to
  * an automatically detected soundcard and videosink. If the NUV file contains
  * compressed audio or video data, this will only work if you have the
  * right decoder elements/plugins installed.
+ * </para>
  * </refsect2>
  *
  */
@@ -60,6 +64,13 @@ GST_DEBUG_CATEGORY_STATIC (nuvdemux_debug);
 
 GST_DEBUG_CATEGORY_EXTERN (GST_CAT_EVENT);
 
+static const GstElementDetails gst_nuv_demux_details =
+GST_ELEMENT_DETAILS ("Nuv demuxer",
+    "Codec/Demuxer",
+    "Demultiplex a mythtv .nuv file into audio and video",
+    "Renato Araujo Oliveira Filho <renato.filho@indt.org.br>,"
+    "Rosfran Borges <rosfran.borges@indt.org.br>");
+
 static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
@@ -124,19 +135,15 @@ gst_nuv_demux_base_init (gpointer klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &audio_src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&audio_src_template));
 
-  gst_element_class_add_static_pad_template (element_class,
-      &video_src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&video_src_template));
 
-  gst_element_class_add_static_pad_template (element_class,
-      &sink_template);
-  gst_element_class_set_details_simple (element_class, "Nuv demuxer",
-      "Codec/Demuxer",
-      "Demultiplex a MythTV NuppleVideo .nuv file into audio and video",
-      "Renato Araujo Oliveira Filho <renato.filho@indt.org.br>,"
-      "Rosfran Borges <rosfran.borges@indt.org.br>");
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&sink_template));
+  gst_element_class_set_details (element_class, &gst_nuv_demux_details);
 }
 
 static void
@@ -188,8 +195,7 @@ gst_nuv_demux_finalize (GObject * object)
   gst_nuv_demux_destoy_src_pad (nuv);
   gst_nuv_demux_reset (nuv);
   if (nuv->adapter != NULL) {
-    g_object_unref (nuv->adapter);
-    nuv->adapter = NULL;
+    gst_object_unref (nuv->adapter);
   }
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -374,9 +380,8 @@ gst_nuv_demux_extended_header_load (GstNuvDemux * nuv,
 
   GST_DEBUG_OBJECT (nuv,
       "ex hdr: v=%d vffc=%4.4s afcc=%4.4s %dHz %dbits ach=%d acr=%d aq=%d"
-      "rtjpeg q=%d lf=%d lc=%d lavc br=%d qmin=%d qmax=%d maxqdiff=%d seekableoff=%"
-      G_GINT64_FORMAT " keyfao=%" G_GINT64_FORMAT, h->i_version,
-      (gchar *) & h->i_video_fcc, (gchar *) & h->i_audio_fcc,
+      "rtjpeg q=%d lf=%d lc=%d lavc br=%d qmin=%d qmax=%d maxqdiff=%d seekableoff=%lld keyfao=%lld",
+      h->i_version, (gchar *) & h->i_video_fcc, (gchar *) & h->i_audio_fcc,
       h->i_audio_sample_rate, h->i_audio_bits_per_sample, h->i_audio_channels,
       h->i_audio_compression_ratio, h->i_audio_quality, h->i_rtjpeg_quality,
       h->i_rtjpeg_luma_filter, h->i_rtjpeg_chroma_filter, h->i_lavc_bitrate,
@@ -488,7 +493,7 @@ gst_nuv_demux_stream_data (GstNuvDemux * nuv)
   switch (h->i_type) {
     case 'V':
     {
-      if (!buf)
+      if (h->i_length == 0)
         break;
 
       GST_BUFFER_OFFSET (buf) = nuv->video_offset;
@@ -499,7 +504,7 @@ gst_nuv_demux_stream_data (GstNuvDemux * nuv)
     }
     case 'A':
     {
-      if (!buf)
+      if (h->i_length == 0)
         break;
 
       GST_BUFFER_OFFSET (buf) = nuv->audio_offset;
@@ -637,7 +642,7 @@ gst_nuv_demux_stream_extend_header (GstNuvDemux * nuv)
     nuv->state = GST_NUV_DEMUX_INVALID_DATA;
     GST_ELEMENT_ERROR (nuv, STREAM, DEMUX, (NULL),
         ("Unsupported extended header (0x%02x)", buf->data[0]));
-    gst_buffer_unref (buf);
+    g_object_unref (buf);
     return GST_FLOW_ERROR;
   }
   return res;
@@ -729,9 +734,7 @@ gst_nuv_demux_play (GstPad * pad)
 pause:
   GST_LOG_OBJECT (nuv, "pausing task, reason %s", gst_flow_get_name (res));
   gst_pad_pause_task (nuv->sinkpad);
-  if (res == GST_FLOW_UNEXPECTED) {
-    gst_nuv_demux_send_eos (nuv);
-  } else if (res == GST_FLOW_NOT_LINKED || res < GST_FLOW_UNEXPECTED) {
+  if (GST_FLOW_IS_FATAL (res)) {
     GST_ELEMENT_ERROR (nuv, STREAM, FAILED,
         (_("Internal data stream error.")),
         ("streaming stopped, reason %s", gst_flow_get_name (res)));
@@ -801,7 +804,7 @@ gst_nuv_demux_sink_activate (GstPad * sinkpad)
   if (gst_pad_check_pull_range (sinkpad)) {
     nuv->mode = 0;
     if (nuv->adapter != NULL) {
-      g_object_unref (nuv->adapter);
+      gst_object_unref (nuv->adapter);
       nuv->adapter = NULL;
     }
     res = gst_pad_activate_pull (sinkpad, TRUE);
@@ -940,5 +943,5 @@ plugin_init (GstPlugin * plugin)
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     "nuvdemux",
-    "Demuxes MythTV NuppelVideo files",
+    "Demuxes and muxes audio and video",
     plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
